/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = {
    timeout: '120s',
    useSSL: true,
    port: 80,
    sslPort: 443,
    ssl: {
        key:    '/server.key',
        cert:   '/server.crt',
        ca:     [ '/server.crt' ]
    },
    api: {
        base_url: 'https://trafficops:443/api/'
    },
    files: {
        static: '/go/src/github.com/apache/trafficcontrol/traffic_portal/app/dist/public'
    },
    log: null,
    reject_unauthorized: 0
};
